"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_native_background_timer_1 = __importDefault(require("react-native-background-timer"));
var moment_1 = __importDefault(require("moment"));
var backgroundDuration = moment_1.default.duration(27, 'minutes').asMilliseconds();
var modalDuration = moment_1.default.duration(3, 'minutes').asMilliseconds();
var defaultCallback = null;
var currentCallback = null;
var onTimerEnd = null;
var backgroundTimerEndTime = new Date().getTime();
var hideModal = null;
var timeout;
var authenticated = false;
exports.init = function (props) {
    backgroundDuration = moment_1.default
        .duration(props.backgroundTime, 'minutes')
        .asMilliseconds();
    modalDuration = moment_1.default.duration(props.modalTime, 'minutes').asMilliseconds();
    defaultCallback = props.defaultCallback;
    hideModal = props.hideModal;
    onTimerEnd = props.onTimerEnd;
};
exports.getCurrentTimeStamp = function () { return new Date().getTime(); };
exports.getBackgroundTimerEndTime = function () { return backgroundTimerEndTime; };
exports.startSessionTimer = function (cb, interval) {
    var duration = interval || backgroundDuration;
    if (!cb) {
        backgroundTimerEndTime = exports.getCurrentTimeStamp() + duration;
        currentCallback = defaultCallback;
    }
    else {
        currentCallback = cb;
    }
    exports.stopSessionTimer();
    react_native_background_timer_1.default.start();
    timeout = react_native_background_timer_1.default.setInterval(currentCallback, duration);
};
exports.stopSessionTimer = function (isStillAuthed) {
    if (isStillAuthed === void 0) { isStillAuthed = true; }
    react_native_background_timer_1.default.clearInterval(timeout);
    react_native_background_timer_1.default.stop();
    authenticated = isStillAuthed;
};
exports.handleAppStateChangeForBackgroundTimer = function (nextAppState) {
    if (authenticated) {
        if (nextAppState === 'active' &&
            currentCallback === defaultCallback &&
            backgroundTimerEndTime) {
            var currentTime = exports.getCurrentTimeStamp();
            if (backgroundTimerEndTime > currentTime) {
                exports.startSessionTimer(currentCallback, backgroundTimerEndTime - currentTime);
            }
            else if (modalDuration + backgroundTimerEndTime - currentTime <= 0 &&
                onTimerEnd) {
                onTimerEnd();
            }
            else {
                currentCallback();
            }
        }
        else {
            exports.stopSessionTimer();
        }
    }
    else {
        hideModal();
    }
};
exports.formatCountdown = function (countdown) {
    var result = '';
    if (countdown && moment_1.default.isDuration(countdown)) {
        var minutes = countdown.minutes();
        var seconds = countdown.seconds();
        if (minutes < 10) {
            minutes = "0" + minutes;
        }
        if (seconds < 10) {
            seconds = "0" + seconds;
        }
        result = minutes + ":" + seconds;
    }
    return result;
};
